// User Interface
export interface User {
	id: string;
	email: string;
	name: string;
	created: string;
	updated: string;
}

// Product Interface
export interface Product {
	id: string;
	title: string;
	description: string;
	imageUrl: string;
	price: number;
	created: string;
	updated: string;
}

// Cart Item Interface
export interface CartItem {
	id: string;
	user: string; // User ID
	product: string; // Product ID
	quantity: number;
	created: string;
	updated: string;
	expand?: {
		product: Product; // Expanded product details
	};
}

// Favorite Interface
export interface Favorite {
	id: string;
	user: string; // User ID
	product: string; // Product ID
	created: string;
	updated: string;
	expand?: {
		product: Product; // Expanded product details
	};
}

// Order Item Interface
export interface OrderItem {
	product: string; // Product ID
	quantity: number;
	expand?: {
		product: Product; // Expanded product details
	};
}

// Order Interface
export interface Order {
	id: string;
	user: string; // User ID
	items: OrderItem[];
	total: number;
	status: 'pending' | 'processing' | 'shipped' | 'delivered' | 'cancelled';
	created: string;
	updated: string;
	expand?: {
		items: Array<{ product: Product }>; // Expanded product details for each item
	};
}
export interface AuthResponse {
	token: string;
	user: User;
}

// API Error Interface
export interface ApiError {
	message: string;
	code?: number;
	details?: unknown;
}
